1.0.0 API documentation: rotate_normalized_axis.hpp File Reference

| 1.0.0 API documentation

Functions
rotate_normalized_axis.hpp File Reference

GLM_GTX_rotate_normalized_axis More...

Go to the source code of this file.

## Functions
template<typename T , qualifier Q>
GLM_FUNC_DECL mat< 4, 4, T, Q > | rotateNormalizedAxis (mat< 4, 4, T, Q > const &m, T const &angle, vec< 3, T, Q > const &axis)
| Builds a rotation 4 * 4 matrix created from a normalized axis and an angle. More...
template<typename T , qualifier Q>
GLM_FUNC_DECL qua< T, Q > | rotateNormalizedAxis (qua< T, Q > const &q, T const &angle, vec< 3, T, Q > const &axis)
| Rotates a quaternion from a vector of 3 components normalized axis and an angle. More...

## Detailed Description

GLM_GTX_rotate_normalized_axis

See also
  Core features (dependence)
  GLM_GTC_matrix_transform
  GLM_GTC_quaternion

Definition in file rotate_normalized_axis.hpp.